summaryrefslogtreecommitdiff
path: root/gcc/toplev.c
diff options
context:
space:
mode:
authornathan <nathan@138bc75d-0d04-0410-961f-82ee72b054a4>2003-05-03 13:28:33 +0000
committernathan <nathan@138bc75d-0d04-0410-961f-82ee72b054a4>2003-05-03 13:28:33 +0000
commitbca5a169dbd7511850392fce078fac9a2ce8b785 (patch)
tree0d918b616faeef5dd3dd6d2c0124b405c528a109 /gcc/toplev.c
parent50a0654444825108f445422abbcd801610910db4 (diff)
downloadgcc-bca5a169dbd7511850392fce078fac9a2ce8b785.tar.gz
* c-decl.c (pending_invalid_xref_file): Remove.
(pending_invalid_xref_line): Remove. (pending_invalid_xref_location): New. (lookup_label): Use location_t and input_location directly. (lookup_tag): Likewise. (pending_xref_error): Likewise. (c_expand_body_1): Likewise. * c-common.c (x_expand_start_cond): Likewise. * c-semantics.c (genrtl_for_stmt): Likewise. (find_reachable_label): Likewise. * expr.c (expand_expr): Likewise. * integrate.c (output_inline_function): Likewise. * tree-inline.c (find_alloca_call): Likewise. (find_builtin_longjmp_call): Likewise. * gcc.c (input_filename): Make static. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@66425 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/toplev.c')
-rw-r--r--gcc/toplev.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/toplev.c b/gcc/toplev.c
index fc25ca4f1d8..065952b0e27 100644
--- a/gcc/toplev.c
+++ b/gcc/toplev.c
@@ -2130,9 +2130,9 @@ check_global_declarations (vec, len)
}
}
/* Save the current INPUT_FILENAME and LINENO on the top entry in the
INPUT_FILE_STACK. Push a new entry for FILE and LINE, and set the
- INPUT_FILENAME and LINENO accordingly. */
+ INPUT_LOCATION accordingly. */
void
push_srcloc (file, line)
@@ -2154,8 +2154,8 @@ push_srcloc (file, line)
}
/* Pop the top entry off the stack of presently open source files.
- Restore the INPUT_FILENAME and LINENO from the new topmost entry on
- the stack. */
+ Restore the INPUT_LOCATION from the new topmost entry on the
+ stack. */
void
pop_srcloc ()
@@ -2130,9 +2130,9 @@ check_global_declarations (vec, len)
}
}
-/* Save the current INPUT_FILENAME and LINENO on the top entry in the
+/* Save the current INPUT_LOCATION on the top entry in the
INPUT_FILE_STACK. Push a new entry for FILE and LINE, and set the